@@ -5,6 +5,7 @@ from re import error as reerror
 
 from ..inflect import BadChunkingOptionError, NumOutOfRangeError, UnknownClassicalModeError
 from ..inflect import UnknownClassicalModeError, BadNumValueError
+from ..inflect import BadGenderError
 from .. import inflect
 
 class test(unittest.TestCase):
@@ -41,42 +42,36 @@ class test(unittest.TestCase):
         p.classical()
         self.assertEqual(p.classical_dict, inflect.all_classical)
 
-        p.classical(0)
-        self.assertEqual(p.classical_dict, inflect.no_classical)
-
-        p.classical(1)
-        self.assertEqual(p.classical_dict, inflect.all_classical)
+        self.assertRaises(TypeError, p.classical, 0)
+        self.assertRaises(TypeError, p.classical, 1)
+        self.assertRaises(TypeError, p.classical, 'names')
+        self.assertRaises(TypeError, p.classical, 'names', 'zero')
+        self.assertRaises(TypeError, p.classical, 'all')
         
-        p.classical(all=0)
+        p.classical(all=False)
         self.assertEqual(p.classical_dict, inflect.no_classical)
 
-        p.classical('names', 'zero')
+        p.classical(names=True, zero=True)
         mydict = inflect.def_classical.copy()
         mydict.update(dict(names=1,zero=1))
         self.assertEqual(p.classical_dict, mydict)
 
-        p.classical('all')
+        p.classical(all=True)
         self.assertEqual(p.classical_dict, inflect.all_classical)
 
-        p.classical(0)
-        p.classical(names=1, zero=1)
+        p.classical(all=False)
+        p.classical(names=True, zero=True)
         mydict = inflect.def_classical.copy()
-        mydict.update(dict(names=1,zero=1))
+        mydict.update(dict(names=True,zero=True))
         self.assertEqual(p.classical_dict, mydict)
 
-        p.classical(0)
-        p.classical('names', zero=1)
+        p.classical(all=False)
+        p.classical(names=True, zero=False)
         mydict = inflect.def_classical.copy()
-        mydict.update(dict(names=1,zero=1))
+        mydict.update(dict(names=True,zero=False))
         self.assertEqual(p.classical_dict, mydict)
 
-        p.classical(0)
-        p.classical('names', zero=0)
-        mydict = inflect.def_classical.copy()
-        mydict.update(dict(names=1,zero=0))
-        self.assertEqual(p.classical_dict, mydict)
-
-        self.assertRaises(UnknownClassicalModeError, p.classical, 'bogus', reallybogus=1)
+        self.assertRaises(UnknownClassicalModeError, p.classical, bogus=True)
 
     def test_num(self):
         # def num
@@ -120,14 +115,14 @@ class test(unittest.TestCase):
             self.assertEqual(p.inflect(txt), ans, msg='p.inflect("%s") != "%s"' % (txt, ans))
 
         for txt, ans in (
-        ("pl(rock)", "rocks"),
-        ("pl(rock)  pl(child)", "rocks  children"),
-        ("num(2) pl(rock)  pl(child)", "2 rocks  children"),
+        ("plural(rock)", "rocks"),
+        ("plural(rock)  plural(child)", "rocks  children"),
+        ("num(2) plural(rock)  plural(child)", "2 rocks  children"),
 
-        ("pl(rock) plnoun(rock) plverb(rocks) pladj(big) a(ant)",
+        ("plural(rock) plural_noun(rock) plural_verb(rocks) plural_adj(big) a(ant)",
                  "rocks rocks rock big an ant"),
 
-        ("an(rock) no(cat) ordinal(3) numwords(1234) prespart(runs)",
+        ("an(rock) no(cat) ordinal(3) numwords(1234) present_participle(runs)",
                  "a rock no cats 3rd one thousand, two hundred and thirty-four running"),
 
         ("a(cat,0) a(cat,1) a(cat,2) a(cat, 2)", "0 cat a cat 2 cat  2 cat"), # TODO: extra space when space before number. Is this desirable?
@@ -141,7 +136,7 @@ class test(unittest.TestCase):
 
         self.assertEqual(p.pl_sb_user_defined, [])
         p.defnoun('VAX','VAXen')
-        self.assertEqual(p.pl('VAX'),'VAXEN')
+        self.assertEqual(p.plural('VAX'),'VAXEN')
         self.assertEqual(p.pl_sb_user_defined, ['VAX','VAXen'])
 
         self.assertTrue(p.ud_match('word',p.pl_sb_user_defined)
@@ -152,33 +147,33 @@ class test(unittest.TestCase):
                         is None)
 
         p.defnoun('cow','cows|kine')
-        self.assertEqual(p.pl('cow'),'cows')
+        self.assertEqual(p.plural('cow'),'cows')
         p.classical()
-        self.assertEqual(p.pl('cow'),'kine')
+        self.assertEqual(p.plural('cow'),'kine')
         
         self.assertEqual(p.ud_match('cow',p.pl_sb_user_defined),
                         'cows|kine')
 
         p.defnoun('(.+i)o',r'$1i')
-        self.assertEqual(p.pl('studio'),'studii')
+        self.assertEqual(p.plural('studio'),'studii')
         self.assertEqual(p.ud_match('studio',p.pl_sb_user_defined),
                         'studii')
 
         p.defnoun('aviatrix','aviatrices')
-        self.assertEqual(p.pl('aviatrix'),'aviatrices')
+        self.assertEqual(p.plural('aviatrix'),'aviatrices')
         self.assertEqual(p.ud_match('aviatrix',p.pl_sb_user_defined),
                         'aviatrices')
         p.defnoun('aviatrix','aviatrixes')
-        self.assertEqual(p.pl('aviatrix'),'aviatrixes')
+        self.assertEqual(p.plural('aviatrix'),'aviatrixes')
         self.assertEqual(p.ud_match('aviatrix',p.pl_sb_user_defined),
                         'aviatrixes')
         p.defnoun('aviatrix',None)
-        self.assertEqual(p.pl('aviatrix'),'aviatrices')
+        self.assertEqual(p.plural('aviatrix'),'aviatrices')
         self.assertEqual(p.ud_match('aviatrix',p.pl_sb_user_defined),
                         None)
 
         p.defnoun('(cat)',r'$1s')
-        self.assertEqual(p.pl('cat'),'cats')
+        self.assertEqual(p.plural('cat'),'cats')
 
         inflect.STDOUT_ON = False
         self.assertRaises(inflect.BadUserDefinedPatternError, p.defnoun, '(??', None)
@@ -194,15 +189,15 @@ class test(unittest.TestCase):
                          'will','will')
         self.assertEqual(p.ud_match('will',p.pl_v_user_defined),
                          'will')
-        self.assertEqual(p.pl('will'),'will')
+        self.assertEqual(p.plural('will'),'will')
         #TODO: will -> shall. Tests below fail
-        self.TODO(p.plequal('will','shall'),'s:p')
-        self.TODO(p.plverbequal('will','shall'),'s:p')
+        self.TODO(p.compare('will','shall'),'s:p')
+        self.TODO(p.compare_verbs('will','shall'),'s:p')
 
 
         #defadj
         p.defadj('hir','their')
-        self.assertEqual(p.pl('hir'),'their')
+        self.assertEqual(p.plural('hir'),'their')
         self.assertEqual(p.ud_match('hir',p.pl_adj_user_defined),
                         'their')
 
@@ -252,32 +247,32 @@ class test(unittest.TestCase):
     def test_pl(self):
         p = inflect.engine()
         for fn, sing, plur in (
-                            (p.pl, '', ''),
-                            (p.pl, 'cow', 'cows'),
-                            (p.pl, 'thought', 'thoughts'),
-                            (p.pl, 'mouse', 'mice'),
-                            (p.pl, 'knife', 'knives'),
-                            (p.pl, 'knifes', 'knife'),
-                            (p.pl, ' cat  ', ' cats  '),
-                            (p.pl, 'court martial', 'courts martial'),
-                            (p.pl, 'a', 'some'),
-                            (p.pl, 'carmen', 'carmina'),
-                            (p.pl, 'quartz', 'quartzes'),
-                            (p.pl, 'care', 'cares'),
-                            (p.plnoun, '',''),
-                            (p.plnoun, 'cow','cows'),
-                            (p.plnoun, 'thought','thoughts'),
-                            (p.plverb, '', ''),
-                            (p.plverb, 'runs', 'run'),
-                            (p.plverb, 'thought', 'thought'),
-                            (p.plverb, 'eyes', 'eye'),
-                            (p.pladj, '', ''),
-                            (p.pladj, 'a', 'some'),
-                            (p.pladj, 'this', 'these'),
-                            (p.pladj, 'that', 'those'),
-                            (p.pladj, 'my', 'our'),
-                            (p.pladj, "cat's", "cats'"),
-                            (p.pladj, "child's", "children's"),
+                            (p.plural, '', ''),
+                            (p.plural, 'cow', 'cows'),
+                            (p.plural, 'thought', 'thoughts'),
+                            (p.plural, 'mouse', 'mice'),
+                            (p.plural, 'knife', 'knives'),
+                            (p.plural, 'knifes', 'knife'),
+                            (p.plural, ' cat  ', ' cats  '),
+                            (p.plural, 'court martial', 'courts martial'),
+                            (p.plural, 'a', 'some'),
+                            (p.plural, 'carmen', 'carmina'),
+                            (p.plural, 'quartz', 'quartzes'),
+                            (p.plural, 'care', 'cares'),
+                            (p.plural_noun, '',''),
+                            (p.plural_noun, 'cow','cows'),
+                            (p.plural_noun, 'thought','thoughts'),
+                            (p.plural_verb, '', ''),
+                            (p.plural_verb, 'runs', 'run'),
+                            (p.plural_verb, 'thought', 'thought'),
+                            (p.plural_verb, 'eyes', 'eye'),
+                            (p.plural_adj, '', ''),
+                            (p.plural_adj, 'a', 'some'),
+                            (p.plural_adj, 'this', 'these'),
+                            (p.plural_adj, 'that', 'those'),
+                            (p.plural_adj, 'my', 'our'),
+                            (p.plural_adj, "cat's", "cats'"),
+                            (p.plural_adj, "child's", "children's"),
                             ):
             self.assertEqual(fn(sing), plur,
                              msg='%s("%s") == "%s" != "%s"' % (
@@ -295,17 +290,17 @@ class test(unittest.TestCase):
                 ('runs', 1, 'runs'),
                 ('am', 0, 'are'),
                     ):
-            self.assertEqual(p.pl(sing, num), plur)
+            self.assertEqual(p.plural(sing, num), plur)
 
-        p.classical('zero')
-        self.assertEqual(p.pl('cow', 0), 'cow')
-        self.assertEqual(p.pl('cow', 'zero'), 'cow')
-        self.assertEqual(p.pl('runs', 0), 'runs')
-        self.assertEqual(p.pl('am', 0), 'am')
-        self.assertEqual(p.plverb('runs', 1), 'runs')
+        p.classical(zero=True)
+        self.assertEqual(p.plural('cow', 0), 'cow')
+        self.assertEqual(p.plural('cow', 'zero'), 'cow')
+        self.assertEqual(p.plural('runs', 0), 'runs')
+        self.assertEqual(p.plural('am', 0), 'am')
+        self.assertEqual(p.plural_verb('runs', 1), 'runs')
 
-        self.assertEqual(p.pl('die'),'dice')
-        self.assertEqual(p.plnoun('die'),'dice')
+        self.assertEqual(p.plural('die'),'dice')
+        self.assertEqual(p.plural_noun('die'),'dice')
 
     def test_sinoun(self):
         p = inflect.engine()
@@ -313,71 +308,128 @@ class test(unittest.TestCase):
             ('cat', 'cats'),
             ('die', 'dice'),
             ):
-            self.assertEqual(p.sinoun(plur), sing)
-            self.assertEqual(p.inflect('sinoun(%s)' % plur), sing)
+            self.assertEqual(p.singular_noun(plur), sing)
+            self.assertEqual(p.inflect('singular_noun(%s)' % plur), sing)
 
+    def test_gender(self):
+        p = inflect.engine()
+        p.gender('feminine')
+        for sing, plur in (
+            ('she', 'they'),
+            ('herself', 'themselves'),
+            ('hers', 'theirs'),
+            ('to her', 'to them'),
+            ('to herself', 'to themselves'),
+            ):
+            self.assertEqual(p.singular_noun(plur), sing, "singular_noun(%s) == %s != %s" % (plur, p.singular_noun(plur), sing))
+            self.assertEqual(p.inflect('singular_noun(%s)' % plur), sing)
         
+        p.gender('masculine')
+        for sing, plur in (
+            ('he', 'they'),
+            ('himself', 'themselves'),
+            ('his', 'theirs'),
+            ('to him', 'to them'),
+            ('to himself', 'to themselves'),
+            ):
+            self.assertEqual(p.singular_noun(plur), sing, "singular_noun(%s) == %s != %s" % (plur, p.singular_noun(plur), sing))
+            self.assertEqual(p.inflect('singular_noun(%s)' % plur), sing)
 
+        p.gender('gender-neutral')
+        for sing, plur in (
+            ('they', 'they'),
+            ('themself', 'themselves'),
+            ('theirs', 'theirs'),
+            ('to them', 'to them'),
+            ('to themself', 'to themselves'),
+            ):
+            self.assertEqual(p.singular_noun(plur), sing, "singular_noun(%s) == %s != %s" % (plur, p.singular_noun(plur), sing))
+            self.assertEqual(p.inflect('singular_noun(%s)' % plur), sing)
+
+        p.gender('neuter')
+        for sing, plur in (
+            ('it', 'they'),
+            ('itself', 'themselves'),
+            ('its', 'theirs'),
+            ('to it', 'to them'),
+            ('to itself', 'to themselves'),
+            ):
+            self.assertEqual(p.singular_noun(plur), sing, "singular_noun(%s) == %s != %s" % (plur, p.singular_noun(plur), sing))
+            self.assertEqual(p.inflect('singular_noun(%s)' % plur), sing)
+
+        self.assertRaises(BadGenderError, p.gender, 'male')
+
+        for sing, plur, gen in (
+            ('it', 'they', 'neuter'),
+            ('she', 'they', 'feminine'),
+            ('he', 'they', 'masculine'),
+            ('they', 'they', 'gender-neutral'),
+            ('she or he', 'they', 'feminine or masculine'),
+            ('he or she', 'they', 'masculine or feminine'),
+                ):
+            self.assertEqual(p.singular_noun(plur, gender=gen), sing)
+            
+        
     def test_plequal(self):
         p = inflect.engine()
         for fn, sing, plur, res in (
-                    (p.plequal, 'index','index','eq'),
-                    (p.plequal, 'index','indexes','s:p'),
-                    (p.plequal, 'index','indices','s:p'),
-                    (p.plequal, 'indexes','index','p:s'),
-                    (p.plequal, 'indices','index','p:s'),
-                    (p.plequal, 'indices','indexes','p:p'),
-                    (p.plequal, 'indexes','indices','p:p'),
-                    (p.plequal, 'indices','indices','eq'),
-                    (p.plequal, 'opuses','opera','p:p'),
-                    (p.plequal, 'opera','opuses','p:p'),
-                    (p.plequal, 'brothers','brethren','p:p'),                  
-                    (p.plequal, 'cats','cats','eq'),
-                    (p.plequal, 'base', 'basis', False),
-                    (p.plequal, 'syrinx', 'syringe', False),
-                    (p.plequal, 'she', 'he', False),
-                    (p.plequal, 'opus', 'operas', False),
-                    (p.plequal, 'taxi', 'taxes', False),
-                    (p.plequal, 'time', 'Times', False),
-                    (p.plequal, 'time'.lower(), 'Times'.lower(), 's:p'),
-                    (p.plequal, 'courts martial', 'court martial', 'p:s'),
-                    (p.plequal, 'my','my','eq'),
-                    (p.plequal, 'my','our','s:p'),
-                    (p.plequal, 'our','our','eq'),
-                    (p.plnounequal, 'index','index','eq'),
-                    (p.plnounequal, 'index','indexes','s:p'),
-                    (p.plnounequal, 'index','indices','s:p'),
-                    (p.plnounequal, 'indexes','index','p:s'),
-                    (p.plnounequal, 'indices','index','p:s'),
-                    (p.plnounequal, 'indices','indexes','p:p'),
-                    (p.plnounequal, 'indexes','indices','p:p'),
-                    (p.plnounequal, 'indices','indices','eq'),
-                    (p.plverbequal, 'runs','runs','eq'),
-                    (p.plverbequal, 'runs','run','s:p'),
-                    (p.plverbequal, 'run','run','eq'),
-                    (p.pladjequal, 'my','my','eq'),
-                    (p.pladjequal, 'my','our','s:p'),
-                    (p.pladjequal, 'our','our','eq'),
+                    (p.compare, 'index','index','eq'),
+                    (p.compare, 'index','indexes','s:p'),
+                    (p.compare, 'index','indices','s:p'),
+                    (p.compare, 'indexes','index','p:s'),
+                    (p.compare, 'indices','index','p:s'),
+                    (p.compare, 'indices','indexes','p:p'),
+                    (p.compare, 'indexes','indices','p:p'),
+                    (p.compare, 'indices','indices','eq'),
+                    (p.compare, 'opuses','opera','p:p'),
+                    (p.compare, 'opera','opuses','p:p'),
+                    (p.compare, 'brothers','brethren','p:p'),                  
+                    (p.compare, 'cats','cats','eq'),
+                    (p.compare, 'base', 'basis', False),
+                    (p.compare, 'syrinx', 'syringe', False),
+                    (p.compare, 'she', 'he', False),
+                    (p.compare, 'opus', 'operas', False),
+                    (p.compare, 'taxi', 'taxes', False),
+                    (p.compare, 'time', 'Times', False),
+                    (p.compare, 'time'.lower(), 'Times'.lower(), 's:p'),
+                    (p.compare, 'courts martial', 'court martial', 'p:s'),
+                    (p.compare, 'my','my','eq'),
+                    (p.compare, 'my','our','s:p'),
+                    (p.compare, 'our','our','eq'),
+                    (p.compare_nouns, 'index','index','eq'),
+                    (p.compare_nouns, 'index','indexes','s:p'),
+                    (p.compare_nouns, 'index','indices','s:p'),
+                    (p.compare_nouns, 'indexes','index','p:s'),
+                    (p.compare_nouns, 'indices','index','p:s'),
+                    (p.compare_nouns, 'indices','indexes','p:p'),
+                    (p.compare_nouns, 'indexes','indices','p:p'),
+                    (p.compare_nouns, 'indices','indices','eq'),
+                    (p.compare_verbs, 'runs','runs','eq'),
+                    (p.compare_verbs, 'runs','run','s:p'),
+                    (p.compare_verbs, 'run','run','eq'),
+                    (p.compare_adjs, 'my','my','eq'),
+                    (p.compare_adjs, 'my','our','s:p'),
+                    (p.compare_adjs, 'our','our','eq'),
                         ):
             self.assertEqual(fn(sing, plur), res)
 
         for fn, sing, plur, res, badres in (
-                    (p.plequal, "dresses's","dresses'", 'p:p', 'p:s'), # TODO: should return p:p 
-                    (p.pladjequal, "dresses's","dresses'", 'p:p', False), # TODO: should return p:p
+                    (p.compare, "dresses's","dresses'", 'p:p', 'p:s'), # TODO: should return p:p 
+                    (p.compare_adjs, "dresses's","dresses'", 'p:p', False), # TODO: should return p:p
 
                     # TODO: future: support different singulars one day.
-                    (p.plequal, "dress's","dress'",'s:s', 'p:s'),
-                    (p.pladjequal, "dress's","dress'",'s:s', False),
-                    (p.plequal, "Jess's","Jess'",'s:s', 'p:s'),
-                    (p.pladjequal, "Jess's","Jess'",'s:s', False),
+                    (p.compare, "dress's","dress'",'s:s', 'p:s'),
+                    (p.compare_adjs, "dress's","dress'",'s:s', False),
+                    (p.compare, "Jess's","Jess'",'s:s', 'p:s'),
+                    (p.compare_adjs, "Jess's","Jess'",'s:s', False),
                         ):
             self.TODO(fn(sing, plur), res, badres)
 
 
         #TODO: pass upstream. multiple adjective plurals not supported
-        self.assertEqual(p.plequal('your', 'our'), False)
+        self.assertEqual(p.compare('your', 'our'), False)
         p.defadj('my', 'our|your') # what's ours is yours
-        self.TODO(p.plequal('your', 'our'), 'p:p')
+        self.TODO(p.compare('your', 'our'), 'p:p')
 
     def test__pl_reg_plurals(self):
         p = inflect.engine()
@@ -531,17 +583,17 @@ class test(unittest.TestCase):
         p.num(3)
 
 
-        p.classical('herd')
+        p.classical(herd=True)
         self.assertEqual(p._plnoun('swine'), 'swine')
-        p.classical(herd=0)
+        p.classical(herd=False)
         self.assertEqual(p._plnoun('swine'), 'swines')
-        p.classical(persons=1)
+        p.classical(persons=True)
         self.assertEqual(p._plnoun('chairperson'), 'chairpersons')
-        p.classical(persons=0)
+        p.classical(persons=False)
         self.assertEqual(p._plnoun('chairperson'), 'chairpeople')
-        p.classical(ancient=1)
+        p.classical(ancient=True)
         self.assertEqual(p._plnoun('formula'), 'formulae')
-        p.classical(ancient=0)
+        p.classical(ancient=False)
         self.assertEqual(p._plnoun('formula'), 'formulas')
 
 
@@ -579,7 +631,7 @@ class test(unittest.TestCase):
         for sing, plur in ( ('brother', 'brethren'),
                             ('dogma', 'dogmata'),
                             ):
-            self.assertEqual(p.pl(sing), plur)
+            self.assertEqual(p.plural(sing), plur)
 
 
     def test__pl_special_verb(self):
@@ -588,7 +640,7 @@ class test(unittest.TestCase):
         self.assertEqual(p._pl_special_verb('am'), 'are')
         self.assertEqual(p._pl_special_verb('am',0), 'are')
         self.assertEqual(p._pl_special_verb('runs',0), 'run')
-        p.classical('zero')
+        p.classical(zero=True)
         self.assertEqual(p._pl_special_verb('am',0), False)
         self.assertEqual(p._pl_special_verb('am',1), 'am')
         self.assertEqual(p._pl_special_verb('am',2), 'are')
@@ -716,14 +768,14 @@ class test(unittest.TestCase):
                     ('loves', 'loving'),
                     ('spies', 'spying'),
                     ):
-            self.assertEqual(p.prespart(sing), plur)
+            self.assertEqual(p.present_participle(sing), plur)
             
-        self.assertEqual(p.prespart('hoes'), 'hoeing')
-        self.assertEqual(p.prespart('alibis'), 'alibiing')
-        self.assertEqual(p.prespart('is'), 'being')
-        self.assertEqual(p.prespart('are'), 'being')
-        self.assertEqual(p.prespart('had'), 'having')
-        self.assertEqual(p.prespart('has'), 'having')
+        self.assertEqual(p.present_participle('hoes'), 'hoeing')
+        self.assertEqual(p.present_participle('alibis'), 'alibiing')
+        self.assertEqual(p.present_participle('is'), 'being')
+        self.assertEqual(p.present_participle('are'), 'being')
+        self.assertEqual(p.present_participle('had'), 'having')
+        self.assertEqual(p.present_participle('has'), 'having')
         
 
     def test_ordinal(self):
@@ -757,7 +809,7 @@ class test(unittest.TestCase):
         self.assertEqual(millfn(1), ' thousand')
         self.assertEqual(millfn(2), ' million')
         self.assertEqual(millfn(3), ' billion')
-        self.assertEqual(millfn(0), '')
+        self.assertEqual(millfn(0), ' ')
         self.assertEqual(millfn(11), ' decillion')
         inflect.STDOUT_ON = False
         self.assertRaises(NumOutOfRangeError, millfn, 12)
@@ -769,8 +821,8 @@ class test(unittest.TestCase):
         self.assertEqual(unitfn(1,2), 'one million')
         self.assertEqual(unitfn(1,3), 'one billion')
         self.assertEqual(unitfn(5,3), 'five billion')
-        self.assertEqual(unitfn(5,0), 'five')
-        self.assertEqual(unitfn(0,0), '')
+        self.assertEqual(unitfn(5,0), 'five ')
+        self.assertEqual(unitfn(0,0), ' ')
 
     def test_tenfn(self):
         p = inflect.engine()
@@ -780,18 +832,18 @@ class test(unittest.TestCase):
         self.assertEqual(tenfn(0,1,2), 'one million')
         self.assertEqual(tenfn(1,1,2), 'eleven million')
         self.assertEqual(tenfn(1,0,2), 'ten million')
-        self.assertEqual(tenfn(1,0,0), 'ten')
-        self.assertEqual(tenfn(0,0,0), '')
+        self.assertEqual(tenfn(1,0,0), 'ten ')
+        self.assertEqual(tenfn(0,0,0), ' ')
 
     def test_hundfn(self):
         p = inflect.engine()
         hundfn = p.hundfn
         p.number_args = dict(andword='and')
-        self.assertEqual(hundfn(4,3,1,2), 'four hundred and thirty-one million, ')
-        self.assertEqual(hundfn(4,0,0,2), 'four hundred million, ')
-        self.assertEqual(hundfn(4,0,5,2), 'four hundred and five million, ')
-        self.assertEqual(hundfn(0,3,1,2), 'thirty-one million, ')
-        self.assertEqual(hundfn(0,0,7,2), 'seven million, ')
+        self.assertEqual(hundfn(4,3,1,2), 'four hundred and thirty-one  million, ')
+        self.assertEqual(hundfn(4,0,0,2), 'four hundred  million, ')
+        self.assertEqual(hundfn(4,0,5,2), 'four hundred and five  million, ')
+        self.assertEqual(hundfn(0,3,1,2), 'thirty-one  million, ')
+        self.assertEqual(hundfn(0,0,7,2), 'seven  million, ')
 
     def test_enword(self):
         p = inflect.engine()
@@ -807,11 +859,11 @@ class test(unittest.TestCase):
                          'three, four, seven, ')
         
         self.assertEqual(enword('34',2),
-                         'thirty-four, ')
+                         'thirty-four , ')
         self.assertEqual(enword('347',2),
-                         'thirty-four, seven, ')
+                         'thirty-four , seven, ')
         self.assertEqual(enword('34768',2),
-                         'thirty-four, seventy-six, eight, ')
+                         'thirty-four , seventy-six , eight, ')
         self.assertEqual(enword('1',2),
                          'one, ')
         p.number_args['one'] = 'single'
@@ -821,7 +873,7 @@ class test(unittest.TestCase):
         p.number_args['one'] = 'one'
 
         self.assertEqual(enword('134',3),
-                         ' one thirty-four, ')
+                         ' one thirty-four , ')
 
 
         self.assertEqual(enword('0',-1),
@@ -831,23 +883,23 @@ class test(unittest.TestCase):
 
 
         self.assertEqual(enword('3',-1),
-                         'three, ')
+                         'three , ')
         self.assertEqual(enword('12',-1),
-                         'twelve, ')
+                         'twelve , ')
         self.assertEqual(enword('123',-1),
-                         'one hundred and twenty-three, ')
+                         'one hundred and twenty-three  , ')
         self.assertEqual(enword('1234',-1),
-                         'one thousand, two hundred and thirty-four, ')
+                         'one thousand, two hundred and thirty-four  , ')
         self.assertEqual(enword('12345',-1),
-                         'twelve thousand, three hundred and forty-five, ')
+                         'twelve thousand, three hundred and forty-five  , ')
         self.assertEqual(enword('123456',-1),
-                         'one hundred and twenty-three thousand, four hundred and fifty-six, ')
+                         'one hundred and twenty-three  thousand, four hundred and fifty-six  , ')
         self.assertEqual(enword('1234567',-1),
-                         'one million, two hundred and thirty-four thousand, five hundred and sixty-seven, ')
+                         'one million, two hundred and thirty-four  thousand, five hundred and sixty-seven  , ')
 
     def test_numwords(self):
         p = inflect.engine()
-        numwords = p.numwords
+        numwords = p.number_to_words
 
         for n, word in (
             ('1', 'one'),
@@ -860,7 +912,7 @@ class test(unittest.TestCase):
             ('10000000', 'ten million'),
             ('+10', 'plus ten'),
             ('-10', 'minus ten'),
-            ('10.','ten point zero'),
+            ('10.','ten point'),
             ('.10', 'point one zero'),
             ):
             self.assertEqual(numwords(n), word)
@@ -869,7 +921,7 @@ class test(unittest.TestCase):
             #TODO: should be one point two three
             ('1.23', 'one point two three', 'one point twenty-three'), 
             ):
-            self.TODO(numwords(n), word, wrongword)
+            self.assertEqual(numwords(n), word)
             
         for n, txt in (
             (3, 'three bottles of beer on the wall'),
@@ -879,7 +931,7 @@ class test(unittest.TestCase):
             ):
             self.assertEqual("%s%s" % (
                 numwords(n, one='a solitary', zero='no more'),
-                p.pl(" bottle of beer on the wall", n)),
+                p.plural(" bottle of beer on the wall", n)),
                          txt)
 
         self.assertEqual(numwords(0, one='one', zero='zero'), 'zero')
@@ -921,17 +973,15 @@ class test(unittest.TestCase):
         
     def test_numwords_group(self):
         p = inflect.engine()
-        numwords = p.numwords
+        numwords = p.number_to_words
         self.assertEqual(numwords('12345', group=2),
                          'twelve, thirty-four, five')
         #TODO: 'hundred and' missing
         self.TODO(numwords('12345', group=3),
                          'one hundred and twenty-three',
                          'one twenty-three, forty-five')
-        #TODO: answer wrong!
-        self.TODO(numwords('123456', group=3),
-                         'one twenty-three, four fifty-six',
-                         'one twenty-three, six fifty-six')
+        self.assertEqual(numwords('123456', group=3),
+                         'one twenty-three, four fifty-six')
         self.assertEqual(numwords('12345', group=1),
                          'one, two, three, four, five')
         self.assertEqual(numwords('1234th', group=0, andword='and'),
@@ -961,7 +1011,7 @@ class test(unittest.TestCase):
 
     def test_wordlist(self):
         p = inflect.engine()
-        wordlist = p.wordlist
+        wordlist = p.join
         self.assertEqual(wordlist([]),
                          '')
         self.assertEqual(wordlist(('apple',)),
@@ -1011,24 +1061,24 @@ class test(unittest.TestCase):
         
     def test_doc_examples(self):
         p = inflect.engine()
-        self.assertEqual(p.plnoun('I'), 'we')
-        self.assertEqual(p.plverb('saw'), 'saw')
-        self.assertEqual(p.pladj('my'), 'our')
-        self.assertEqual(p.plnoun('saw'), 'saws')
-        self.assertEqual(p.pl('was'), 'were')
-        self.assertEqual(p.pl('was',1), 'was')
-        self.assertEqual(p.plverb('was',2), 'were')
-        self.assertEqual(p.plverb('was'), 'were')
-        self.assertEqual(p.plverb('was',1), 'was')
+        self.assertEqual(p.plural_noun('I'), 'we')
+        self.assertEqual(p.plural_verb('saw'), 'saw')
+        self.assertEqual(p.plural_adj('my'), 'our')
+        self.assertEqual(p.plural_noun('saw'), 'saws')
+        self.assertEqual(p.plural('was'), 'were')
+        self.assertEqual(p.plural('was',1), 'was')
+        self.assertEqual(p.plural_verb('was',2), 'were')
+        self.assertEqual(p.plural_verb('was'), 'were')
+        self.assertEqual(p.plural_verb('was',1), 'was')
 
         for errors, txt in ( (0, 'There were no errors'),
                              (1, 'There was 1 error'),
                              (2, 'There were 2 errors'),
                              ):
-            self.assertEqual("There %s%s" % (p.plverb('was',errors), p.no(" error", errors)),
+            self.assertEqual("There %s%s" % (p.plural_verb('was',errors), p.no(" error", errors)),
                                          txt)
 
-            self.assertEqual(p.inflect("There plverb(was,%d) no(error,%d)" % (errors, errors)),
+            self.assertEqual(p.inflect("There plural_verb(was,%d) no(error,%d)" % (errors, errors)),
                                          txt)
 
 
@@ -1039,15 +1089,15 @@ class test(unittest.TestCase):
                                 ):
             self.assertEqual("%s%s%s %s%s" % (
                             p.num(num1,""),
-                            p.pl("I"),
-                            p.plverb(" saw"),
+                            p.plural("I"),
+                            p.plural_verb(" saw"),
                             p.num(num2),
-                            p.plnoun(" saw")
+                            p.plural_noun(" saw")
                             ),
                             txt)
             
             self.assertEqual(p.inflect(
-                'num(%d,)pl(I) plverb(saw) num(%d) plnoun(saw)' % (num1, num2)
+                'num(%d,)plural(I) plural_verb(saw) num(%d) plural_noun(saw)' % (num1, num2)
                             ),
                             txt)
 
@@ -1060,10 +1110,29 @@ class test(unittest.TestCase):
             ('ewe', 'a ewe'),
             ('hour', 'an hour'),
             ):
-            self.assertEqual(p.a('%s %s' % (p.numwords(1, one='a'),word)), txt)
+            self.assertEqual(p.a('%s %s' % (p.number_to_words(1, one='a'),word)), txt)
 
         p.num(2)
 
+    def test_deprecation(self):
+        p = inflect.engine()
+        for meth in ('pl',
+                     'plnoun',
+                     'plverb',
+                     'pladj',
+                     'sinoun',
+                     'prespart',
+                     'numwords',
+                     'plequal',
+                     'plnounequal',
+                     'plverbequal',
+                     'pladjequal',
+                     'wordlist',
+                     ):
+            self.assertRaises(DeprecationWarning, getattr, p, meth)
+
+
+
 #TODO: test .inflectrc file code        
 
 if __name__ == "__main__":
